@@ -18,11 +18,19 @@ import time
 
 class Xvfb:
 
-    def __init__(self, width=800, height=680, colordepth=24):
+    def __init__(self, width=800, height=680, colordepth=24, **kwargs):
         self.width = width
         self.height = height
         self.colordepth = colordepth
 
+        self.xvfb_cmd = [
+            '-screen', '0', '%dx%dx%d' %
+            (self.width, self.height, self.colordepth)
+        ]
+
+        for key, value in kwargs.items():
+            self.xvfb_cmd = self.xvfb_cmd + ['-%s' % key, value]
+
         self.proc = None
         if 'DISPLAY' in os.environ:
             self.old_display_num = os.environ['DISPLAY'].split(':')[1]
@@ -31,15 +39,19 @@ class Xvfb:
 
     def start(self):
         self.vdisplay_num = self.search_for_free_display()
-        self.xvfb_cmd = [
-            'Xvfb', ':%d' % (self.vdisplay_num,), '-screen', '0',
-            '%dx%dx%d' % (self.width, self.height, self.colordepth)
-        ]
+        self.xvfb_cmd = ['Xvfb', ':%d' % self.vdisplay_num] + self.xvfb_cmd
+
         self.proc = subprocess.Popen(self.xvfb_cmd,
                                      stdout=open(os.devnull),
-                                     stderr=open(os.devnull))
+                                     stderr=open(os.devnull),
+                                     )
         time.sleep(0.1)  # give Xvfb time to start
-        self._redirect_display(self.vdisplay_num)
+        ret_code = self.proc.poll()
+        if ret_code is None:
+            self._redirect_display(self.vdisplay_num)
+        else:
+            self.proc = None
+            print('Error: Xvfb did not start')
 
     def stop(self):
         self._redirect_display(self.old_display_num)
